@@ -1,3 +1,5 @@
+import asyncio
+from copy import copy
 from datetime import datetime
 from enum import IntEnum
 from typing import (
@@ -138,7 +140,12 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
         return obj
 
     async def after_update(
-        self, user: UserModel, obj: Model, input: UpdateForm, request: Request
+        self,
+        user: UserModel,
+        old_obj: Model,
+        input: UpdateForm,
+        obj: Model,
+        request: Request,
     ) -> Any:
         return obj
 
@@ -184,6 +191,22 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
     def connection_name(self):
         return self.model._meta.default_connection  # type: ignore
 
+    async def get(
+        self, ids: str, user: UserModel, request: Request, method: ResourceMethod
+    ):
+        normalize_ids = await asyncio.gather(
+            *[self.translate_id(user, id.strip(), request) for id in ids.split(",")]
+        )
+        objs = await self.q(
+            user,
+            request,
+            self.model.filter(id__in=normalize_ids),
+            method,
+        ).all()
+        if len(objs) != len(normalize_ids):
+            raise HTTPNotFoundError
+        return objs
+
     def bind(self, router: APIRouter):
         ListPydanticModel = self.model.list()
         DetailPydanticModel = self.model.detail()
@@ -333,7 +356,14 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                             v = self.translate_condition(current_user, q, k, v, request)
                             if isinstance(v, QuerySet):
                                 q = cast(QuerySet[Model], v)
-                            elif v is not None:
+                            elif (
+                                v is not None
+                                and v != ""
+                                and not (isinstance(v, list) and not v)
+                                and not (isinstance(v, dict) and not v)
+                            ):
+                                if v == "$empty":
+                                    v = ""
                                 q_kwargs[k] = v
                         condition_q = Q(
                             **q_kwargs,
@@ -419,16 +449,9 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
             ) -> Any:
                 async with in_transaction(self.connection_name):
                     rtns: List[Any] = []
-                    for id in ids.split(","):
-                        id = id.strip()
-                        id = await self.translate_id(current_user, id, request)
-                        obj = await self.q(
-                            current_user,
-                            request,
-                            self.model.filter(id=id),
-                            ResourceMethod.put,
-                        ).get()
-
+                    for obj in await self.get(
+                        ids, current_user, request, ResourceMethod.put
+                    ):
                         r = await self.before_update(current_user, obj, input, request)
                         if r:
                             obj = r
@@ -442,6 +465,8 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                                     if obj.updated_at > updated_at:
                                         raise HTTPPreconditionRequiredError
 
+                            obj_obj = copy(obj)
+
                             update_fields = raw.keys()
                             if update_fields:
                                 obj.update(raw)
@@ -451,7 +476,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                                 await obj.fetch_related(*prefetch)
 
                             obj_rtn = await self.after_update(
-                                current_user, obj, input, request
+                                current_user, obj_obj, input, obj, request
                             )
                             if obj_rtn:
                                 obj = obj_rtn
@@ -479,17 +504,12 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
             ) -> Union[List[DeleteResponse], DeleteResponse]:
                 async with in_transaction(self.connection_name):
                     rs: List[DeleteResponse] = []
-                    for id in ids.split(","):
-                        id = await self.translate_id(current_user, id, request)
-                        obj = await self.q(
-                            current_user,
-                            request,
-                            self.model.filter(id=id),
-                            ResourceMethod.delete,
-                        ).get()
+                    for obj in await self.get(
+                        ids, current_user, request, ResourceMethod.delete
+                    ):
                         obj = await self.before_delete(current_user, obj, request)
                         await obj.delete()
-                        rs.append(DeleteResponse(id=id))
+                        rs.append(DeleteResponse(id=obj.id))
                     return len(rs) > 1 and rs or rs[0]
 
             methods["delete"] = delete
