@@ -1,7 +1,6 @@
 import re
 from typing import Any, List, Match, Optional, Tuple, Union
 
-import inflection
 from fastapi import FastAPI, HTTPException, Request, status
 from fastapi.exceptions import RequestValidationError
 from fastapi.responses import ORJSONResponse
@@ -18,7 +17,6 @@ from pydantic.error_wrappers import ErrorWrapper
 from tortoise import exceptions
 
 from ..logging import getLogger
-from ..model import BaseModel
 from ..model.enum import EnumMissingError
 
 logger = getLogger(__name__)
@@ -104,35 +102,17 @@ def translate_orm_error(
         args: List[str] = []
         for arg in e.args:
             regxps = [
-                "UNIQUE constraint failed: (\\S+)\\.(\\S+)",
-                ".+Duplicate entry '(\\S+)' for key '(\\S+)\\.(\\S+)'.+",
+                ".*Duplicate entry '(.+)' for key.*",
+                "UNIQUE constraint failed: .*",
             ]
             matched: Optional[Match[str]] = None
             for regxp in regxps:
                 matched = re.match(regxp, str(arg))
                 if matched:
-                    groups = matched.groups()
-                    if len(groups) == 2:
-                        groups = ("", *groups)
-                    value = groups[0]
-                    model_name = inflection.camelize(groups[1])
-                    field_name = groups[2]
-                    model, field = BaseModel.get_field(model_name, field_name)
-                    field_description = (
-                        field
-                        and getattr(field, "description", None)
-                        or inflection.humanize(field_name)
-                    )
-                    meta = model and getattr(model, "Meta", None)
-                    model_title = (
-                        meta
-                        and getattr(
-                            meta, "title", model and inflection.humanize(model.__name__)
-                        )
-                        or "对象"
-                    )
                     status_code = status.HTTP_409_CONFLICT
-                    arg = f"{field_description} 为 {value} 的{model_title}已存在"
+                    groups = matched.groups()
+                    value = groups and groups[0] or ""
+                    arg = f"值为 {value} 的对象已存在" if value else "对象已存在"
                     break
             if not matched:
                 logger.with_field(arg=arg, type=type(arg)).warn("not translate")
